<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Gutentor_Pro_Featured_Img_Popup_Hooks' ) ) {

	/**
	 * Block Specific Hooks Class For Gutentor
	 *
	 * @package Gutentor
	 * @since 2.0.0
	 */
	class Gutentor_Pro_Featured_Img_Popup_Hooks {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @return object
		 * @since 2.0.0
		 */
		public static function get_instance() {
			// Store the instance locally to avoid private static replication
			static $instance = null;

			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance
			return $instance;

		}

		/**
		 * Add Filter
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_filter( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Add Action
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_action( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Run Block
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function run() {
			/*Block Specific PHP hooks*/
			$this->add_filter( 'gutentor_edit_post_module_featured_image_popup_data', $this, 'add_popup_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_p6_featured_image_popup_data', $this, 'add_p6_popup_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_post_module_post_item', $this, 'add_image_popup_parent_classes', 10, 3 );
			$this->add_filter( 'gutentor_p6_featured_post_post_item', $this, 'add_p6_image_popup_parent_classes', 10, 2 );
			$this->add_filter( 'gutentor_post_module_t5_item_height', $this, 'add_image_popup_wrap_classes', 10, 3 );
			$this->add_filter( 'gutentor_post_module_post_item_height', $this, 'add_image_popup_wrap_classes', 10, 3 );
			$this->add_filter( 'gutentor_p6_featured_post_post_item_height', $this, 'add_p6_popup_wrap_classes', 10, 2 );
		}

		/**
		 * Check if check_popup_access
		 *
		 * @param {array} $attributes
		 *
		 * @return {boolean}
		 */
		public function check_popup_access( $attributes ) {

			$pt        = ( isset( $attributes['pPostType'] ) ) ? $attributes['pPostType'] : false;
			$videoInPt = gutentor_setting_videos_in_pt();
			$videoInPt = ( is_array( $videoInPt ) ) ? $videoInPt : array();
			if ( ! in_array( $pt, $videoInPt ) ) {
				return false;
			}
			$gutentorBlockName = ( isset( $attributes['gName'] ) ) ? $attributes['gName'] : '';
			$block_list        = array( 'gutentor/p1', 'gutentor/p2', 'gutentor/p6' );
			if ( ! in_array( $gutentorBlockName, $block_list ) ) {
				return false;
			}
			if ( $gutentorBlockName === 'gutentor/p1' ) {
				$template = ( isset( $attributes['p1Temp'] ) ) ? $attributes['p1Temp'] : '';
				if ( $template !== 'gutentor_p1_template5' ) {
					return false;
				}
				$thumbnail_enable = isset( $attributes['pOnFImg'] ) ? $attributes['pOnFImg'] : false;
				if ( ! $thumbnail_enable ) {
					return false;
				}
			}
			if ( $gutentorBlockName === 'gutentor/p6' ) {
				$template = ( isset( $attributes['p6Temp'] ) ) ? $attributes['p6Temp'] : '';
				if ( $template !== 'gutentor_p6_template1' ) {
					return false;
				}
				$thumbnail_enable = isset( $attributes['pOnFPFImg'] ) ? $attributes['pOnFPFImg'] : false;
				if ( ! $thumbnail_enable ) {
					return false;
				}
			}
			return true;
		}

		/**
		 * Adding Avatar Classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_popup_featured_image( $output, $post, $attributes ) {

			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}
			$local_data = '';
			$fVideoType = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : false;
			if ( $fVideoType !== 'popup' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFPopupData'] ) ) ? $attributes['pFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$local_data       .= $output;
						$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
						$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
						$local_data   .= '<a class="g-v-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= $output;
					$iconClass    = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data  .= '<a class="g-v-btn" href="' . $upload_video_url . '">
                    <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding Featured Classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_p6_popup_featured_image( $output, $post, $attributes ) {
			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}

			$local_data = '';
			$fVideoType = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : false;
			if ( $fVideoType !== 'popup' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFFPopupData'] ) ) ? $attributes['pFFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$local_data   .= $output;
					$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
					$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data   .= '<a class="g-v-fp-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= $output;
				$iconClass        = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
				$local_data      .= '<a class="g-v-fp-btn" href="' . $upload_video_url . '">
                    <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding add_image_popup_parent_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_image_popup_parent_classes( $output, $attributes ) {

			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}
			$local_data = $output;
			$pFVType    = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : '';
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-popup' );
				$local_data = gutentor_concat_space( $local_data, 'g-v-popup-enabled' );
			}
			return $local_data;

		}

		/**
		 * Adding add_p6_image_popup_parent_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_p6_image_popup_parent_classes( $output, $attributes ) {

			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}
			$local_data = $output;
			$pFVType    = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : '';
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-fp-popup g-v-fp-popup-enabled' );
			}
			return $local_data;

		}

		/**
		 * Adding add_image_popup_wrap_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_image_popup_wrap_classes( $output, $attributes ) {

			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}
			$local_data   = $output;
			$pFVType      = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : '';
			$popupData    = ( isset( $attributes['pFPopupData'] ) ) ? $attributes['pFPopupData'] : '';
			$iconPosition = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-img-box', $iconPosition );
			}
			return $local_data;

		}

		/**
		 * Adding add_p6_popup_wrap_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_p6_popup_wrap_classes( $output, $attributes ) {

			if ( ! $this->check_popup_access( $attributes ) ) {
				return $output;
			}
			$local_data   = $output;
			$popupData    = ( isset( $attributes['pFFPopupData'] ) ) ? $attributes['pFFPopupData'] : '';
			$iconPosition = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			$pFVType      = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : '';
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-fp-img-box', $iconPosition );
			}
			return $local_data;

		}
	}
}

/**
 * Return instance of  Gutentor_Pro_Featured_Img_Popup_Hooks class
 *
 * @since    1.0.0
 */
if ( ! function_exists( 'gutentor_pro_featured_img_popup_hooks' ) ) {

	function gutentor_pro_featured_img_popup_hooks() {
		return Gutentor_Pro_Featured_Img_Popup_Hooks::get_instance();
	}
}
gutentor_pro_featured_img_popup_hooks()->run();
