<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Gutentor_Pro_Post_Modules_Hooks' ) ) {

	/**
	 * Block Specific Hooks Class For Gutentor
	 *
	 * @package Gutentor
	 * @since 2.0.0
	 */
	class Gutentor_Pro_Post_Modules_Hooks {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @return object
		 * @since 2.0.0
		 */
		public static function get_instance() {
			// Store the instance locally to avoid private static replication
			static $instance = null;

			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance
			return $instance;

		}

		/**
		 * Add Filter
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_filter( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Add Action
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_action( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Run Block
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function run() {
			/*Block Specific PHP hooks*/
			$this->add_filter( 'gutentor_has_post_featured', $this, 'enable_has_post_featured', 10, 3 );
			$this->add_filter( 'gutentor_save_post_module_featured_image_data', $this, 'add_video_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_p6_post_module_featured_image_data', $this, 'add_p6_video_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_save_post_module_featured_image_data', $this, 'add_popup_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_p6_post_module_featured_image_data', $this, 'add_p6_popup_featured_image', 10, 3 );
			$this->add_filter( 'gutentor_post_module_post_image_box', $this, 'add_post_image_box_classes', 10, 3 );
			$this->add_filter( 'gutentor_p6_fp_post_module_post_image_box', $this, 'add_p6_post_image_box_classes', 10, 3 );
		}

		/**
		 * enable_has_post_featured
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function enable_has_post_featured( $output, $post ) {

			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );
			if ( $video_src_option === 'external-url' && $video_url ) {
				return true;
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				return true;
			}
			return $output;

		}

		/**
		 * Check if check_video_access
		 *
		 * @param {array} $attributes
		 *
		 * @return {boolean}
		 */
		public function check_video_access( $attributes ) {

			$pt        = ( isset( $attributes['pPostType'] ) ) ? $attributes['pPostType'] : false;
			$videoInPt = gutentor_setting_videos_in_pt();
			$videoInPt = ( is_array( $videoInPt ) ) ? $videoInPt : array();
			if ( ! in_array( $pt, $videoInPt ) ) {
				return false;
			}
			$gutentorBlockName = ( isset( $attributes['gName'] ) ) ? $attributes['gName'] : '';
			$block_list        = array( 'gutentor/p1', 'gutentor/p6' );
			if ( ! in_array( $gutentorBlockName, $block_list ) ) {
				return false;
			}
			if ( $gutentorBlockName === 'gutentor/p1' ) {
				$template       = ( isset( $attributes['p1Temp'] ) ) ? $attributes['p1Temp'] : '';
				 $template_list = array( 'gutentor_p1_template1', 'gutentor_p1_template2' );
				$post_type      = ( isset( $attributes['pPostType'] ) ) ? $attributes['pPostType'] : 'post';
				if ( 'download' === $post_type && 'gutentor_p1_template4' === $template ) {
					$template_list[] = 'gutentor_p1_template4';
				}
				if ( ! in_array( $template, $template_list ) ) {
					return false;
				}
				$thumbnail_enable = isset( $attributes['pOnFImg'] ) ? $attributes['pOnFImg'] : false;
				if ( ! $thumbnail_enable ) {
					return false;
				}
			}
			if ( $gutentorBlockName === 'gutentor/p6' ) {
				$template      = ( isset( $attributes['p6Temp'] ) ) ? $attributes['p6Temp'] : '';
				$template_list = array( 'gutentor_p6_template1', 'gutentor_p6_template2' );
				if ( ! in_array( $template, $template_list ) ) {
					return false;
				}
				$thumbnail_enable = isset( $attributes['pOnFPFImg'] ) ? $attributes['pOnFPFImg'] : false;
				if ( ! $thumbnail_enable ) {
					return false;
				}
			}
			return true;
		}


		/**
		 * Adding Avatar Classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_video_featured_image( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}

			$local_data = '';
			if ( isset( $attributes['pFType'] ) && $attributes['pFType'] !== 'video' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFPopupData'] ) ) ? $attributes['pFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$iconPosition     = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			$overlay_obj      = ( isset( $attributes['pFImgOColor'] ) ) ? $attributes['pFImgOColor'] : false;
			$fVideoType       = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : false;
			$overlay_enable   = ( $overlay_obj && array_key_exists( 'enable', $overlay_obj ) ) ? $attributes['pFImgOColor']['enable'] : false;
			$overlay          = ( $overlay_enable ) ? 'gutentor-overlay' : '';
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$videoUrl    = 'https://www.youtube.com/embed/' . $youtubeVideoID;
					$local_data .= '<div class="' . gutentor_concat_space( 'g-v-box', $overlay, $iconPosition ) . '">';
					if ( $videoUrl && $attributes['pFType'] === 'video' ) {
						$local_data .= '<iframe
                                height="100%"
                                width="100%"
                                class="g-v-player"
                                src="' . $videoUrl . '"
                                frameborder="0"
                                allowfullscreen
                            >
                            </iframe>';
					}
					if ( $fVideoType === 'popup' ) {
						$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
						$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
						$local_data   .= '<a class="g-v-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
					}
					$local_data .= '</div>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= '<div class="' . gutentor_concat_space( 'g-v-box', $overlay, $iconPosition ) . '">';
				if ( $upload_video_url && $attributes['pFType'] === 'video' ) {
					$local_data .= '<video 
                            playsinline
                            autoplay
                            class="g-v-player"
                            >
                                <source
                                    type="video/mp4"
                                    src="' . $upload_video_url . '"
                                />
                            </video>';
				}
				if ( $fVideoType === 'popup' ) {
					$iconClass   = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data .= '<a class="g-v-btn" href="' . $upload_video_url . '">
                    <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
				}
				$local_data .= '</div>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding p6 video featured image
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_p6_video_featured_image( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}
			$local_data = '';
			if ( isset( $attributes['pFFType'] ) && $attributes['pFFType'] !== 'video' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFFPopupData'] ) ) ? $attributes['pFFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$iconPosition     = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			$overlay_obj      = ( isset( $attributes['pFPFImgOColor'] ) ) ? $attributes['pFPFImgOColor'] : false;
			$fVideoType       = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : false;
			$overlay_enable   = ( $overlay_obj && array_key_exists( 'enable', $overlay_obj ) ) ? $attributes['pFPFImgOColor']['enable'] : false;
			$overlay          = ( $overlay_enable ) ? 'gutentor-overlay' : '';
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$videoUrl    = 'https://www.youtube.com/embed/' . $youtubeVideoID;
					$local_data .= '<div class="' . gutentor_concat_space( 'g-v-fp-box', $overlay, $iconPosition ) . '">';
					if ( $videoUrl && $attributes['pFFType'] === 'video' ) {
						$local_data .= '<iframe
                                height="100%"
                                width="100%"
                                class="g-v-fp-player"
                                src="' . $videoUrl . '"
                                frameborder="0"
                                allowfullscreen
                            >
                            </iframe>';
					}
					if ( $fVideoType === 'popup' ) {
						$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
						$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
						$local_data   .= '<a class="g-v-fp-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
					}
					$local_data .= '</div>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= '<div class="' . gutentor_concat_space( 'g-v-fp-box', $overlay, $iconPosition ) . '">';
				if ( $upload_video_url && $attributes['pFFType'] === 'video' ) {
					$local_data .= '<video 
                            playsinline
                            autoplay
                            class="g-v-fp-player"
                            >
                                <source
                                    type="video/mp4"
                                    src="' . $upload_video_url . '"
                                />
                            </video>';
				}
				if ( $fVideoType === 'popup' ) {
					$iconClass   = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data .= '<a class="g-v-fp-btn" href="' . $upload_video_url . '">
                    <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
				}
				$local_data .= '</div>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding Avatar Classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_popup_featured_image( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}

			$local_data = '';
			if ( isset( $attributes['pFType'] ) && $attributes['pFType'] !== 'img' ) {
				return $output;
			}
			$fVideoType = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : false;
			if ( $fVideoType !== 'popup' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFPopupData'] ) ) ? $attributes['pFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$iconPosition     = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			$overlay_obj      = ( isset( $attributes['pFImgOColor'] ) ) ? $attributes['pFImgOColor'] : false;
			$overlay_enable   = ( $overlay_obj && array_key_exists( 'enable', $overlay_obj ) ) ? $attributes['pFImgOColor']['enable'] : false;
			$overlay          = ( $overlay_enable ) ? 'gutentor-overlay' : '';
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$local_data       .= '<div class="' . gutentor_concat_space( 'g-v-img-box', $iconPosition ) . '">';
					$local_data       .= $output;
						$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
						$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
						$local_data   .= '<a class="g-v-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
					$local_data       .= '</div>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= '<div class="' . gutentor_concat_space( 'g-v-img-box', $iconPosition ) . '">';
				$local_data      .= $output;
					$iconClass    = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data  .= '<a class="g-v-btn" href="' . $upload_video_url . '">
                    <span class="g-v-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
				$local_data      .= '</div>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding Featured Classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return string
		 */
		public function add_p6_popup_featured_image( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}

			$local_data = '';
			if ( isset( $attributes['pFFType'] ) && $attributes['pFFType'] !== 'img' ) {
				return $output;
			}
			$fVideoType = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : false;
			if ( $fVideoType !== 'popup' ) {
				return $output;
			}
			$popupData        = ( isset( $attributes['pFFPopupData'] ) ) ? $attributes['pFFPopupData'] : '';
			$popupIconClass   = $popupData && ( isset( $popupData['icon'] ) ) ? $popupData['icon'] : false;
			$iconPosition     = $popupData && ( isset( $popupData['iPos'] ) ) ? $popupData['iPos'] : false;
			$overlay_obj      = ( isset( $attributes['pFPFImgOColor'] ) ) ? $attributes['pFPFImgOColor'] : false;
			$overlay_enable   = ( $overlay_obj && array_key_exists( 'enable', $overlay_obj ) ) ? $attributes['pFPFImgOColor']['enable'] : false;
			$overlay          = ( $overlay_enable ) ? 'gutentor-overlay' : '';
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			if ( $video_src_option === 'external-url' && $video_url ) {
				$youtubeVideoID = gutentor_get_youtube_id_from_url( $video_url );
				if ( $youtubeVideoID ) {
					$local_data   .= '<div class="' . gutentor_concat_space( 'g-v-fp-img-box', $iconPosition ) . '">';
					$local_data   .= $output;
					$popupVideoUrl = 'https://www.youtube.com/watch?v=' . $youtubeVideoID;
					$iconClass     = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
					$local_data   .= '<a class="g-v-fp-btn" href="' . $popupVideoUrl . '">
                        <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                    </a>';
					$local_data   .= '</div>';
				}
			}
			if ( $video_src_option === 'self-hosted' && $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				$local_data      .= '<div class="' . gutentor_concat_space( 'g-v-fp-img-box', $iconPosition ) . '">';
				$local_data      .= $output;
				$iconClass        = ( $popupIconClass && $popupIconClass['value'] ) ? $popupIconClass['value'] : false;
				$local_data      .= '<a class="g-v-fp-btn" href="' . $upload_video_url . '">
                    <span class="g-v-fp-icon"><i class="' . $iconClass . '"></i></span>
                </a>';
				$local_data      .= '</div>';
			}
			$local_data = empty( $local_data ) ? $output : $local_data;
			return $local_data;

		}

		/**
		 * Adding post_image_box_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_post_image_box_classes( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}

			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			$local_data        = $output;
			$local_video_class = '';
			$pFType            = ( isset( $attributes['pFType'] ) ) ? $attributes['pFType'] : '';
			$pFVType           = ( isset( $attributes['pFVType'] ) ) ? $attributes['pFVType'] : '';
			$post_type         = ( isset( $attributes['pPostType'] ) ) ? $attributes['pPostType'] : 'post';
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-popup' );
				$local_data = gutentor_concat_space( $local_data, 'g-v-popup-enabled' );
			}
			$thumb_class = ( has_post_thumbnail() ) ? '' : 'g-v-popup-no-thumb';
			if ( $post_type === 'product' && $thumb_class === 'g-v-popup-no-thumb' ) {
				$thumb_class = WC()->plugin_url() . '/assets/images/placeholder.png' ? '' : $thumb_class;
			}
			if ( $post_type === 'download' && $thumb_class === 'g-v-popup-no-thumb' ) {
				$download_url = GUTENTOR_URL . 'assets/img/default-image.jpg';
				$thumb_class  = $download_url ? '' : $thumb_class;
			}
			if ( $pFType === 'img' && $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, $thumb_class );
			}
			if ( $pFType === 'video' && $video_src_option === 'external-url' && $video_url ) {
				$local_video_class = 'g-has-video';
			}
			if ( $pFType === 'video' && $video_src_option === 'self-hosted' && $video_id ) {
				$local_video_class = 'g-has-video';
			}
			if ( $local_video_class ) {
				$local_data = gutentor_concat_space( $local_data, $local_video_class );
			}
			return $local_data;

		}

		/**
		 * Adding post_image_box_classes
		 *
		 * @param {array} output
		 * @param {object} props
		 * @return {array}
		 */
		public function add_p6_post_image_box_classes( $output, $post, $attributes ) {

			if ( ! $this->check_video_access( $attributes ) ) {
				return $output;
			}

			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );

			$local_data        = $output;
			$local_video_class = '';
			$post_type         = ( isset( $attributes['pPostType'] ) ) ? $attributes['pPostType'] : 'post';
			$pFType            = ( isset( $attributes['pFFType'] ) ) ? $attributes['pFFType'] : '';
			$pFVType           = ( isset( $attributes['pFFVType'] ) ) ? $attributes['pFFVType'] : '';
			if ( $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, 'g-v-fp-popup' );
				$local_data = gutentor_concat_space( $local_data, 'g-v-fp-popup-enabled' );
			}
			$thumb_class = ( has_post_thumbnail() ) ? '' : 'g-v-popup-no-thumb';
			if ( $post_type === 'product' && $thumb_class === 'g-v-popup-no-thumb' ) {
				$thumb_class = WC()->plugin_url() . '/assets/images/placeholder.png' ? '' : $thumb_class;
			}
			if ( $post_type === 'download' && $thumb_class === 'g-v-popup-no-thumb' ) {
				$download_url = GUTENTOR_URL . 'assets/img/default-image.jpg';
				$thumb_class  = $download_url ? '' : $thumb_class;
			}
			if ( $pFType === 'img' && $pFVType === 'popup' ) {
				$local_data = gutentor_concat_space( $local_data, $thumb_class );
			}
			if ( $pFType === 'video' && $video_src_option === 'external-url' && $video_url ) {
				$local_video_class = 'g-fp-has-video';
			}
			if ( $pFType === 'video' && $video_src_option === 'self-hosted' && $video_id ) {
				$local_video_class = 'g-fp-has-video';
			}
			if ( $local_video_class ) {
				$local_data = gutentor_concat_space( $local_data, $local_video_class );
			}
			return $local_data;

		}

	}
}

/**
 * Return instance of  Gutentor_Pro_Post_Modules_Hooks class
 *
 * @since    1.0.0
 */
if ( ! function_exists( 'gutentor_pro_post_modules_hooks' ) ) {

	function gutentor_pro_post_modules_hooks() {
		return Gutentor_Pro_Post_Modules_Hooks::get_instance();
	}
}
gutentor_pro_post_modules_hooks()->run();
