<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Gutentor_Pro_P1_Hooks' ) ) {

	/**
	 * Block Specific Hooks Class For Gutentor
	 *
	 * @package Gutentor
	 * @since 2.0.0
	 */
	class Gutentor_Pro_P1_Hooks {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @return object
		 * @since 2.0.0
		 */
		public static function get_instance() {
			// Store the instance locally to avoid private static replication
			static $instance = null;

			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance
			return $instance;

		}

		/**
		 * Add Filter
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_filter( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Add Action
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_action( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Run Block
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function run() {
			/*Block Specific PHP hooks*/
			$this->add_filter( 'gutentor_post_module_main_wrap_class', $this, 'add_masonry_enable_class', 9999, 2 );
		}



		/**
		 * Adding masonry class
		 *
		 * @param {array} output
		 * @param {object}       $attributes
		 * @return {mix}
		 */
		public function add_masonry_enable_class( $output, $attributes ) {

			$gutentorBlockName = ( isset( $attributes['gName'] ) ) ? $attributes['gName'] : '';
			$block_list        = array( 'gutentor/p1' );
			if ( ! in_array( $gutentorBlockName, $block_list ) ) {
				return $output;
			}
			$pMsyOn = isset( $attributes['pMsyOn'] ) ? $attributes['pMsyOn'] : false;

			if ( ! $pMsyOn ) {
				return $output;
			}
			$timeline       = isset( $attributes['pTimeline'] ) ? $attributes['pTimeline'] : false;
			$timelineEnable = is_array( $timeline ) && array_key_exists( 'enable', $timeline ) ? $timeline['enable'] : false;
			$gStyle         = $attributes['gStyle'] ? $attributes['gStyle'] : '';
			$template       = $attributes['p1Temp'] ? $attributes['p1Temp'] : '';
			if ( $gStyle === 'gutentor-blog-list' || $timelineEnable ) {
				return $output;
			}
			$template_list = array( 'gutentor_p1_template1', 'gutentor_p1_template2', 'gutentor_p1_template5' );
			if ( ! in_array( $template, $template_list ) ) {
				return $output;
			}
			$pImgDisplayType = ( isset( $attributes['pImgDisplayType'] ) ) ? $attributes['pImgDisplayType'] : false;
			if ( $template === 'gutentor_p1_template5' && $pImgDisplayType !== 'normal-image' ) {
				return $output;
			}
			return gutentor_concat_space( $output, 'g-masonry' );
		}
	}
}

/**
 * Return instance of  Gutentor_Pro_P1_Hooks class
 *
 * @since    1.0.0
 */
if ( ! function_exists( 'gutentor_pro_p1_hooks' ) ) {

	function gutentor_pro_p1_hooks() {
		return Gutentor_Pro_P1_Hooks::get_instance();
	}
}
gutentor_pro_p1_hooks()->run();
