<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Gutentor_Pro_TimeLine' ) ) {

	/**
	 * Block Specific Hooks Class For Gutentor
	 *
	 * @package Gutentor
	 * @since 2.0.0
	 */
	class Gutentor_Pro_TimeLine {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @return object
		 * @since 2.0.0
		 */
		public static function get_instance() {
			// Store the instance locally to avoid private static replication
			static $instance = null;

			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance
			return $instance;

		}

		/**
		 * Add Filter
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_filter( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Add Action
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
			add_action( $hook, array( $component, $callback ), $priority, $accepted_args );
		}

		/**
		 * Run Block
		 *
		 * @access public
		 * @return void
		 * @since 2.0.0
		 */
		public function run() {
			/*Block Specific PHP hooks*/
			$this->add_filter( 'gutentor_post_and_term_module_enable_column', $this, 'remove_grid_class', 8, 2 );
			$this->add_filter( 'gutentor_post_module_main_wrap_class', $this, 'add_timeline_enable_class', 9999, 2 );
			$this->add_filter( 'gutentor_post_module_grid_row_class', $this, 'replace_row_class', 9999, 2 );
			$this->add_filter( 'gutentor_post_module_p1_query_data_after', $this, 'add_timeline_html', 9999, 3 );
		}

		/**
		 * Check if check_timeline_access
		 *
		 * @param {array} $attributes
		 *
		 * @return {boolean}
		 */
		public function check_timeline_access( $attributes ) {

			$gutentorBlockName = ( isset( $attributes['gName'] ) ) ? $attributes['gName'] : '';
			$block_list        = array( 'gutentor/p1' );
			if ( ! in_array( $gutentorBlockName, $block_list ) ) {
				return false;
			}
			if ( $gutentorBlockName === 'gutentor/p1' ) {
				$timeline       = isset( $attributes['pTimeline'] ) ? $attributes['pTimeline'] : false;
				$timelineEnable = array_key_exists( 'enable', $timeline ) ? $timeline['enable'] : false;
				if ( $timelineEnable ) {
					return true;
				}
			}
			return false;
		}

		/**
		 * Remove Grid Class
		 *
		 * @param {array} output
		 * @param {object} attributes
		 * @return string
		 */
		public function remove_grid_class( $output, $attributes ) {
			if ( ! $this->check_timeline_access( $attributes ) ) {
				return $output;
			}
			return false;
		}


		/**
		 * Adding main class
		 *
		 * @param {array} output
		 * @param {object}       $attributes
		 * @return {mix}
		 */
		public function add_timeline_enable_class( $output, $attributes ) {

			if ( ! $this->check_timeline_access( $attributes ) ) {
				return $output;
			}
			return gutentor_concat_space( $output, 'g-timeline' );
		}


		/**
		 * Adding replace_row_class
		 *
		 * @param {array} output
		 * @param {object}       $attributes
		 * @return {mix}
		 */
		public function replace_row_class( $output, $attributes ) {

			if ( ! $this->check_timeline_access( $attributes ) ) {
				return $output;
			}
			return 'g-timeline-article-wrap';
		}

		/**
		 * add_timeline_html
		 *
		 * @param {string} $data
		 * @param {array}  $post
		 * @param {array}  $attributes
		 * @return {mix}
		 */
		public function add_timeline_html( $data, $post, $attributes ) {
			$output = '';
			if ( ! $this->check_timeline_access( $attributes ) ) {
				return $data;
			}
			$timeline           = isset( $attributes['pTimeline'] ) ? $attributes['pTimeline'] : false;
			$timelineIcon       = is_array( $timeline ) && array_key_exists( 'icon', $timeline ) ? $timeline['icon'] : false;
			$timelineIconEnable = is_array( $timeline ) && array_key_exists( 'iEnable', $timeline ) ? $timeline['iEnable'] : false;
			$output            .= '<div class="g-timeline-node">';
			if ( $timelineIcon && $timelineIconEnable ) {
				$output .= '<span class="g-timeline-node-icon">';
				$output .= ( $timelineIcon['value'] ) ? '<i class="' . $timelineIcon['value'] . '" ></i>' : '';
				$output .= '</span>';
			}
			$output .= '</div>';
			return $output;
		}
	}
}

/**
 * Return instance of  Gutentor_Pro_TimeLine class
 *
 * @since    1.0.0
 */
if ( ! function_exists( 'gutentor_pro_timeline' ) ) {

	function gutentor_pro_timeline() {
		return Gutentor_Pro_TimeLine::get_instance();
	}
}
gutentor_pro_timeline()->run();
