<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'Gutentor_Blog_Templates' ) ) {

	/**
	 * Blog_Post_Templates Class For Gutentor
	 *
	 * @package Gutentor
	 * @since 2.0.0
	 */
	class Gutentor_Blog_Templates extends Gutentor_Blog_Query_Elements {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @since 2.0.0
		 * @return object
		 */
		public static function get_instance() {

			// Store the instance locally to avoid private static replication
			static $instance = null;
			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance
			return $instance;

		}

		/**
		 * Run Block
		 *
		 * @access public
		 * @since 2.0.0
		 * @return void
		 */
		public function run() {
			add_filter(
				'gutentor_save_blog_post_block_template_data',
				array(
					$this,
					'load_blog_post_template',
				),
				10,
				3
			);
		}

		/**
		 * Load Template 2
		 *
		 * @param {string} $data
		 * @param {array}  $post
		 * @param {array}  $attributes
		 *
		 * @return {mix}
		 */
		function template2( $data, $post, $attributes ) {

			$output  = $this->get_title( $post, $attributes );
			$output .= '<div class="entry-meta">';
			$output .= $this->get_date( $post, $attributes );
			$output .= $this->get_author( $post, $attributes );
			$output .= $this->get_category_list( $post, $attributes );
			$output .= '</div>';
			$output .= '<div class="gutentor-post-wrap">';
			$output .= $this->get_featured_image( $post, $attributes );
			$output .= '<div class="gutentor-post-content">';
			$output .= $this->get_description( $post, $attributes );
			$output .= $this->get_button( $post, $attributes );
			$output .= '</div>';
			$output .= '</div>';
			return $output;
		}

		/**
		 * Load Template 3
		 *
		 * @param {string} $data
		 * @param {array}  $post
		 * @param {array}  $attributes
		 *
		 * @return {mix}
		 */
		function template3( $data, $post, $attributes ) {

			$output  = '<header>';
			$output .= $this->get_category_list( $post, $attributes );
			$output .= $this->get_title( $post, $attributes );
			$output .= '</header>';
			$output .= '<div class="gutentor-post-wrap">';
			$output .= $this->get_featured_image( $post, $attributes );
			$output .= '<div class="gutentor-post-content">';
			$output .= '<div class="entry-meta">';
			$output .= $this->get_date( $post, $attributes );
			$output .= $this->get_author( $post, $attributes );
			$output .= '</div>';
			$output .= $this->get_description( $post, $attributes );
			$output .= $this->get_button( $post, $attributes );
			$output .= '</div>';
			$output .= '</div>';
			return $output;
		}

		/**
		 * Load Template 4
		 *
		 * @param {string} $data
		 * @param {array}  $post
		 * @param {array}  $attributes
		 *
		 * @return {mix}
		 */
		function template4( $data, $post, $attributes ) {

			$output  = '';
			$output .= $this->get_featured_image( $post, $attributes );
			$output .= '<div class="gutentor-post-wrap">';
			$output .= '<header>';
			$output .= $this->get_category_list( $post, $attributes );
			$output .= $this->get_title( $post, $attributes );
			$output .= '</header>';
			$output .= '<div class="gutentor-post-content">';
			$output .= '<div class="entry-meta">';
			$output .= $this->get_date( $post, $attributes );
			$output .= $this->get_author( $post, $attributes );
			$output .= '</div>';
			$output .= $this->get_description( $post, $attributes );
			$output .= $this->get_button( $post, $attributes );
			$output .= '</div>';
			$output .= '</div>';
			return $output;
		}

		/**
		 * Blog Post Templates
		 *
		 * @param {string} $data
		 * @param {array}  $post
		 * @param {array}  $attributes
		 *
		 * @return {mix}
		 */
		public function load_blog_post_template( $data, $post, $attributes ) {

			$output = $data;
			if ( 'blog-template2' == $attributes['blockBlogTemplate'] ) {
				$output = $this->template2( $data, $post, $attributes );
			} elseif ( 'blog-template3' == $attributes['blockBlogTemplate'] ) {
				$output = $this->template3( $data, $post, $attributes );
			} elseif ( 'blog-template4' == $attributes['blockBlogTemplate'] ) {
				$output = $this->template4( $data, $post, $attributes );
			}
			return $output;
		}

	}
}
Gutentor_Blog_Templates::get_instance()->run();
