<?php
/**
 * Gutentor Custom Icons
 *
 * @since 1.0.0
 */

if ( ! class_exists( 'Gutentor_Icons' ) ) {
	/**
	 * Class Gutentor_Icons.
	 */
	class Gutentor_Icons {

		public $post_type = 'gutentor-icons';

		/**
		 * Main Gutentor_Icons Instance
		 * Initialize the class and set its properties.
		 *
		 * @since    1.0.0
		 * @return object $instance Gutentor_Icons Instance
		 */
		public static function instance() {

			// Store the instance locally to avoid private static replication
			static $instance = null;

			// Only run these methods if they haven't been ran previously
			if ( null === $instance ) {
				$instance = new Gutentor_Icons();
			}

			// Always return the instance
			return $instance;
		}

		public function run() {
			add_action( 'init', array( $this, 'register_post_type_gutentor_icons' ) );
			add_action( 'admin_menu', array( $this, 'add_post_type_submenu' ) );

			add_action( 'wp_ajax_gutentor_save_icons', array( $this, 'save_icons' ) );
			add_action( 'wp_ajax_gutentor_delete_icons', array( $this, 'delete_icons' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'dynamic_css_enqueue' ), 9999 );

			add_filter( 'gutentor_block_editor_localize_data', array( $this, 'add_localize_data' ), 98 );
			if ( is_admin() ) {
				add_action( 'load-post.php', array( $this, 'init_metabox' ) );
				add_action( 'load-post-new.php', array( $this, 'init_metabox' ) );
			}
		}

		/**
		 * Adding new mime types.
		 *
		 * @access public
		 * @since    1.0.0
		 * @param  array $mimes    existing mime types.
		 * @return array
		 */
		public function file_extension( $mimes = array() ) {
			return array(
				'txt',
				'css',
				'js',
				'html',
				'json',
				'eot',
				'svg',
				'ttf',
				'woff',
				'woff2',
				'eot',
			);
		}

		/**
		 * Source Type
		 *
		 * @access public
		 * @since    1.0.0
		 * @param  array $all_files    existing mime types.
		 * @return string
		 */
		public function source_type( $all_files ) {
			foreach ( (array) $all_files as $file ) {
				if ( strpos( $file, 'selection.json' ) !== false ) {
					return 'icomoon';
				}
				if ( strpos( $file, 'config.json' ) !== false ) {
					return 'fontello';
				}
			}
			return '';
		}

		public function get_preview( $meta_icons ) {
			$preview = '';
			if ( $meta_icons && is_array( $meta_icons ) ) {
				foreach ( $meta_icons as $icon ) {
					$preview .= '<div id="gutentor-single-icon-preview"><i class="' . esc_attr( $icon['value'] ) . '"></i></div>';
				}
			}
			return $preview;

		}

		public function save_icons() {
			if ( isset( $_FILES['gutentor-upload-zip-archive']['name'] ) && ! empty( $_FILES['gutentor-upload-zip-archive']['name'] ) ) {
				/*check for security*/
				if ( ! current_user_can( 'upload_files' ) ) {
					wp_send_json_error(
						array(
							'message' => esc_html__( 'Sorry, you are not allowed to upload files on this site.', 'gutentor' ),
						)
					);
				}
				if ( ! current_user_can( 'edit_post', $_POST['post_id'] ) ) {
					wp_send_json_error(
						array(
							'message' => esc_html__( 'Sorry, you are not allowed to edit the post.', 'gutentor' ),
						)
					);
				}

				if ( ! isset( $_POST['gutentor_meta_nonce'] ) ||
					! wp_verify_nonce( $_POST['gutentor_meta_nonce'], basename( __FILE__ ) ) ) {
						wp_send_json_error(
							array(
								'message' => esc_html__( 'Permission denied', 'gutentor' ),
							)
						);
				}

				/*file process*/
				require_once ABSPATH . 'wp-admin/includes/file.php';
				WP_Filesystem();
				global  $wp_filesystem;
				$upload_dir         = wp_upload_dir();
				$upload_path        = '/gutentor-pro/custom-icons/' . absint( $_POST['post_id'] );
				$icon_path          = $upload_dir['basedir'] . $upload_path;
				$upload_zip_archive = $_FILES['gutentor-upload-zip-archive'];
				$wp_filesystem->rmdir( $icon_path, true );
				$unzipfile = unzip_file( $upload_zip_archive['tmp_name'], $icon_path );
				if ( is_wp_error( $unzipfile ) ) {
					wp_send_json_error(
						array(
							'message' => esc_html__( 'Error on unzipping, Please try again', 'gutentor' ),
						)
					);
				}
				/*(check) Zip should contain json file and uploads folder only*/
				$prepare_data = array();
				$all_files    = gutentor_get_dir_contents( $icon_path );

				foreach ( (array) $all_files as $file ) {
					$array     = explode( '.', $file );
					$extension = end( $array );
					if ( strpos( $file, 'config.json' ) !== false ) {
						$prepare_data['type']   = 'fontello';
						$file_info              = json_decode( file_get_contents( $file ) );
						$prepare_data['name']   = trim( $file_info->name );
						$prepare_data['prefix'] = $file_info->css_prefix_text;
						$prepare_data['icons']  = $file_info->glyphs;
					} elseif ( strpos( $file, 'selection.json' ) !== false ) {
						$prepare_data['type']   = 'icomoon';
						$file_info              = json_decode( file_get_contents( $file ) );
						$prepare_data['name']   = trim( $file_info->name );
						$prepare_data['icons']  = $file_info->icons;
						$prepare_data['prefix'] = $file_info->preferences->fontPref->prefix;
					}
					if ( ! in_array( $extension, $this->file_extension() ) ) {
						$wp_filesystem->rmdir( $icon_path, true );
						wp_send_json_error(
							array(
								'message' => sprintf( esc_html__( 'Invalid Zip File %s', 'gutentor' ), $extension ),
							)
						);
					}
				}

				if ( ! $this->source_type( $all_files ) ) {
					$wp_filesystem->rmdir( $icon_path, true );
					wp_send_json_error(
						array(
							'message' => sprintf( esc_html__( 'Invalid Zip File %s', 'gutentor' ), $extension ),
						)
					);
				} else {
					if ( 'icomoon' === $this->source_type( $all_files ) ) {
						foreach ( (array) $all_files as $file ) {
							if ( strpos( $file, 'style.css' ) !== false ) {
								$array               = explode( $_POST['post_id'], $file );
								$prepare_data['url'] = trailingslashit( $upload_dir['baseurl'] . $upload_path ) . str_replace( '\\', '/', end( $array ) );
								break;
							}
						}
					} elseif ( 'fontello' === $this->source_type( $all_files ) ) {
						$css_file_name = 'fontello.css';
						if ( $prepare_data['name'] ) {
							$css_file_name = $prepare_data['name'] . '.css';
						}
						foreach ( (array) $all_files as $file ) {
							if ( strpos( $file, $css_file_name ) !== false ) {
								$array               = explode( $_POST['post_id'], $file );
								$prepare_data['url'] = trailingslashit( $upload_dir['baseurl'] . $upload_path ) . str_replace( '\\', '/', end( $array ) );
								break;
							}
						}
					}
				}
				$meta_icons = array();
				if ( 'fontello' === $prepare_data['type'] ) {
					foreach ( $prepare_data['icons'] as $icon_data ) {
						$meta_icons[] = array(
							'label' => $prepare_data['prefix'] . $icon_data->css,
							'value' => $prepare_data['prefix'] . $icon_data->css,
							'code'  => $icon_data->code,
						);
					}
				} elseif ( 'icomoon' === $prepare_data['type'] ) {
					foreach ( $prepare_data['icons'] as $icon_data ) {
						$meta_icons[] = array(
							'label' => $prepare_data['prefix'] . $icon_data->properties->name,
							'value' => $prepare_data['prefix'] . $icon_data->properties->name,
							'code'  => $icon_data->properties->code,
						);

					}
				}
				$preview = $this->get_preview( $meta_icons );
				update_post_meta( $_POST['post_id'], 'gutentor-icons', $meta_icons );
				update_post_meta( $_POST['post_id'], 'gutentor-icon-url', $prepare_data['url'] );

				wp_send_json_success(
					array(
						'message'   => esc_html__( 'Success', 'gutentor' ),
						'iconsInfo' => array(
							'icons'   => $meta_icons,
							'url'     => $prepare_data['url'],
							'type'    => $prepare_data['type'],
							'name'    => $prepare_data['name'],
							'prefix'  => $prepare_data['prefix'],
							'preview' => $preview,
						),
					)
				);
			}
			wp_send_json_error(
				array(
					'message' => esc_html__( 'No Zip File Found', 'gutentor' ),
				)
			);
		}

		public function delete_icons() {
			if ( ! current_user_can( 'edit_post', $_POST['post_id'] ) ) {
				wp_send_json_error(
					array(
						'message' => esc_html__( 'Sorry, you are not allowed to edit the post.', 'gutentor' ),
					)
				);
			}

			if ( ! isset( $_POST['gutentor_meta_nonce'] ) ||
				! wp_verify_nonce( $_POST['gutentor_meta_nonce'], basename( __FILE__ ) ) ) {
				wp_send_json_error(
					array(
						'message' => esc_html__( 'Permission denied', 'gutentor' ),
					)
				);
			}

			/*file process*/
			require_once ABSPATH . 'wp-admin/includes/file.php';
			WP_Filesystem();
			global  $wp_filesystem;
			$upload_dir  = wp_upload_dir();
			$upload_path = '/gutentor-pro/custom-icons/' . absint( $_POST['post_id'] );
			$icon_path   = $upload_dir['basedir'] . $upload_path;
			$wp_filesystem->rmdir( $icon_path, true );

			$meta_icons = get_post_meta( $_POST['post_id'], 'gutentor-icons', true );
			delete_post_meta( $_POST['post_id'], 'gutentor-icons', $meta_icons );

			$icon_url = get_post_meta( $_POST['post_id'], 'gutentor-icon-url', true );
			delete_post_meta( $_POST['post_id'], 'gutentor-icon-url', $icon_url );

			wp_send_json_success(
				array(
					'message' => esc_html__( 'Success', 'gutentor' ),
				)
			);
		}

		public function set_dynamic_icons_transists() {
			delete_transient( 'gutentor_dynamic_icons' );

			$args      = array(
				'post_type'   => $this->post_type,
				'post_status' => 'publish',
			);
			$the_query = new WP_Query( $args );

			$add_data = array();
			if ( $the_query->have_posts() ) {
				while ( $the_query->have_posts() ) {
					$the_query->the_post();
					$icon_url = get_post_meta( get_the_ID(), 'gutentor-icon-url', true );
					$icons    = get_post_meta( get_the_ID(), 'gutentor-icons', true );

					$add_data[] = array(
						'id'      => get_the_ID(),
						'name'    => get_the_title(),
						'url'     => $icon_url,
						'version' => time(),
						'icons'   => $icons,
					);

				}
			}
			if ( empty( $add_data ) ) {
				$add_data = 'no-dynamic-fonts';
			}

			set_transient( 'gutentor_dynamic_icons', $add_data );
			wp_reset_postdata();
		}

		public function add_localize_data( $localize_data ) {
			$this->dynamic_css_enqueue();
			if ( get_transient( 'gutentor_dynamic_icons' ) ) {
				$localize_data['dynamic-icons'] = get_transient( 'gutentor_dynamic_icons' );
			}
			return $localize_data;
		}

		public function dynamic_css_enqueue() {

			$dynamic_fonts = get_transient( 'gutentor_dynamic_icons' );
			if ( is_array( $dynamic_fonts ) && ! empty( $dynamic_fonts ) ) {
				foreach ( $dynamic_fonts as $font ) {
					wp_enqueue_style( 'gutentor-dynamic-fonts-' . $font['id'], $font['url'], false, isset( $font['version'] ) ? $font['version'] : '' );
				}
			}
		}
		/**
		 * Register the register_post_type.
		 *
		 * @since    1.0.0
		 */
		public function add_post_type_submenu() {
			add_submenu_page(
				'gutentor',
				_x( 'All Icons', 'Post type general name', 'gutentor' ),
				_x( 'Icons', 'Post type general name', 'gutentor' ),
				'manage_options',
				'edit.php?post_type=gutentor-icons'
			);
		}

		/**
		 * Register the register_post_type.
		 *
		 * @since    1.0.0
		 */
		public function register_post_type_gutentor_icons() {

			$labels = apply_filters(
				'gutentor_post_type_icons_label',
				array(
					'name'                  => _x( 'Icons', 'Post type general name', 'gutentor' ),
					'singular_name'         => _x( 'Icon', 'Post type singular name', 'gutentor' ),
					'menu_name'             => _x( 'Icons', 'Admin Menu text', 'gutentor' ),
					'name_admin_bar'        => _x( 'Icon', 'Add New on Toolbar', 'gutentor' ),
					'add_new'               => esc_html__( 'Add New', 'gutentor' ),
					'add_new_item'          => esc_html__( 'Add New Icon', 'gutentor' ),
					'new_item'              => esc_html__( 'New Icon', 'gutentor' ),
					'edit_item'             => esc_html__( 'Edit Icon', 'gutentor' ),
					'view_item'             => esc_html__( 'View Icon', 'gutentor' ),
					'all_items'             => esc_html__( 'All Icons', 'gutentor' ),
					'search_items'          => esc_html__( 'Search Icons', 'gutentor' ),
					'parent_item_colon'     => esc_html__( 'Parent Icons:', 'gutentor' ),
					'not_found'             => esc_html__( 'No documentations found.', 'gutentor' ),
					'not_found_in_trash'    => esc_html__( 'No documentations found in Trash.', 'gutentor' ),
					'featured_image'        => _x( 'Icon Cover Image', 'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'gutentor' ),
					'set_featured_image'    => _x( 'Set cover image', 'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'gutentor' ),
					'remove_featured_image' => _x( 'Remove cover image', 'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'gutentor' ),
					'use_featured_image'    => _x( 'Use as cover image', 'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'gutentor' ),
					'archives'              => _x( 'Icon archives', 'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'gutentor' ),
					'insert_into_item'      => _x( 'Insert into documentation', 'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4', 'gutentor' ),
					'uploaded_to_this_item' => _x( 'Uploaded to this documentation', 'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4', 'gutentor' ),
					'filter_items_list'     => _x( 'Filter documentations list', 'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4', 'gutentor' ),
					'items_list_navigation' => _x( 'Icons list navigation', 'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Pages list navigation”. Added in 4.4', 'gutentor' ),
					'items_list'            => _x( 'Icons list', 'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4', 'gutentor' ),
				)
			);

			$args = apply_filters(
				'gutentor_post_type_icons_args',
				array(
					'labels'             => $labels,
					'public'             => false,
					'publicly_queryable' => false,
					'show_ui'            => true,
					'show_in_menu'       => false,
					'query_var'          => true,
					'show_in_rest'       => true,
					'rewrite'            => false,
					'capability_type'    => 'post',
					'has_archive'        => false,
					'hierarchical'       => false,
					'menu_position'      => 999,
					'menu_icon'          => 'dashicons-admin-site',
					'supports'           => array( 'title', 'author' ),
				)
			);

			register_post_type( $this->post_type, $args );

			/*
			register_post_meta(
				$this->post_type,
				'gutentor-icon-url',
				array(
					'show_in_rest' => true,
					'single'       => true,
					'type'         => 'string',
				)
			);
			register_post_meta(
				$this->post_type,
				'gutentor-icons',
				array(
					'single'       => true,
					'type'         => 'array',
					'show_in_rest' => array(
						'schema' => array(
							'items' => array(
								'type'       => 'object',
								'properties' => array(
									'value' => array(
										'type' => 'string',
									),
									'label'  => array(
										'type' => 'string',
									),
								),
							),
						),
					),
				)
			);*/
		}

		/**
		 * Meta box initialization.
		 */
		public function init_metabox() {

			add_action( 'add_meta_boxes', array( $this, 'add_metabox' ) );
			add_action( 'save_post', array( $this, 'save_metabox' ), 10, 2 );

		}

		/**
		 * Adds the meta box.
		 * On icons
		 */
		public function add_metabox() {
			add_meta_box(
				'gutentor_meta_box',
				__( 'Icon Info', 'gutentor' ),
				array( $this, 'render_metabox' ),
				$this->post_type,
				'normal',
				'high'
			);
		}

		/**
		 * Renders the meta box.
		 */
		public function render_metabox( $post ) {

			// Scripts.
			wp_enqueue_script(
				'gutentor-custom-icons', // Handle.
				plugins_url( '/assets/js/custom-icons.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
				array( 'jquery' ), // Dependencies, defined above.
				GUTENTOR_PRO_VERSION, // Version: File modification time.
				true // Enqueue the script in the footer.
			);

			$localize = array(
				'ajax_url'   => admin_url( 'admin-ajax.php' ),
				'ajax_nonce' => wp_create_nonce( 'gutentor-nonce' ),
				'post_id'    => get_the_ID(),
			);
			wp_localize_script( 'gutentor-custom-icons', 'GUTENTOR_CUSTOM_ICONS', $localize );

			/*Item Icon URL*/
			$icon_url = get_post_meta( $post->ID, 'gutentor-icon-url', true );
			$icons    = get_post_meta( $post->ID, 'gutentor-icons', true );

			/*Security nonce*/
			wp_nonce_field( basename( __FILE__ ), 'gutentor_meta_nonce' );
			?>
			<div class="gutentor-icon-callback components-base-control">

				<div class="components-base-control__field">
					<?php
					$file_is_hidden   = '';
					$delete_is_hidden = 'hidden';
					if ( $icon_url && $icons ) {
						$file_is_hidden   = 'hidden';
						$delete_is_hidden = '';
					}
					?>
					<div id="gutentor-icon-info" class="<?php echo $file_is_hidden; ?>" >
						<?php echo sprintf( esc_html__( 'Upload zip file downloaded from  %1$sFontello%2$s and  %3$sIcomoon%4$s.', 'gutentor' ), '<a href="https://fontello.com/" target="_blank" rel="nofollow noreferrer noopener">', '</a>', '<a href="https://icomoon.io/app/" target="_blank" rel="nofollow noreferrer noopener">', '</a>' ); ?>
					   <br>
						<?php esc_html_e( 'Please note that the CSS prefix for the icon name should be unique for each font.', 'gutentor' ); ?>
					</div>
					<input id="gutentor-icons-files" name="files[]" type="file" accept=".zip" class="<?php echo $file_is_hidden; ?>">
					<div id="gutentor-icons-preview">
						<link href="<?php echo esc_url( $icon_url ); ?>" rel="stylesheet">
						<?php echo $this->get_preview( $icons ); ?>
					</div>
					<button class="button button-secondary <?php echo $delete_is_hidden; ?>" id="gutentor-icons-delete">
						<?php esc_html_e( 'Delete', 'gutentor' ); ?>
					</button>
				</div>
			</div>
			<?php
		}

		/**
		 * Handles saving the meta box.
		 *
		 * @param int     $post_id Post ID.
		 * @param WP_Post $post    Post object.
		 * @return null
		 */
		public function save_metabox( $post_id, $post ) {

			/*
			  * A Guide to Writing Secure Themes – Part 4: Securing Post Meta
			  *https://make.wordpress.org/themes/2015/06/09/a-guide-to-writing-secure-themes-part-4-securing-post-meta/
			  * */
			if (
				! isset( $_POST['gutentor_meta_nonce'] ) ||
				! wp_verify_nonce( $_POST['gutentor_meta_nonce'], basename( __FILE__ ) ) || /*Protecting against unwanted requests*/
				( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || /*Dealing with autosaves*/
				! current_user_can( 'edit_post', $post_id )/*Verifying access rights*/
			) {
				return;
			}

			if ( $this->post_type != $_POST['post_type'] ) {
				return $post_id;
			}
			if ( ! current_user_can( 'edit_post', $post_id ) ) {
				return $post_id;
			}

			$this->set_dynamic_icons_transists();
		}
	}
}

/**
 * Begins execution of the hooks.
 *
 * @since    1.0.0
 */
function gutentor_icons() {
	return Gutentor_Icons::instance();
}
gutentor_icons()->run();
