<?php

if ( ! function_exists( 'gutentor_pro_is_edit_page' ) ) {
	function gutentor_pro_is_edit_page() {
		// make sure we are on the backend
		if ( ! is_admin() ) {
			return false;
		}
		global $pagenow;
		return in_array( $pagenow, array( 'post.php', 'post-new.php' ) );
	}
}


/**
 * Gutentor Setting
 */
if ( ! function_exists( 'gutentor_setting_videos_in_pt' ) ) {

	function gutentor_setting_videos_in_pt() {
		$get_video_setting = gutentor_get_options( 'videos-in-pt' );
		if ( $get_video_setting ) {
			return $get_video_setting;
		}
		return false;
	}
}


/**
 * Gutentor Setting
 */
if ( ! function_exists( 'gutentor_get_dir_contents' ) ) {

	function gutentor_get_dir_contents( $dir, $filter = '', &$results = array() ) {
		$files = scandir( $dir );

		foreach ( $files as $key => $value ) {
			$path = realpath( $dir . DIRECTORY_SEPARATOR . $value );

			if ( ! is_dir( $path ) ) {
				if ( empty( $filter ) || preg_match( $filter, $path ) ) {
					$results[] = $path;
				}
			} elseif ( $value != '.' && $value != '..' ) {
				gutentor_get_dir_contents( $path, $filter, $results );
			}
		}

		return $results;
	}
}


/**
 * Get ACF Fields by post type
 *
 * @since    3.1.9

 * @return [boolean]
 */
if ( ! function_exists( 'gutentor_get_acf_fields_by_location' ) ) {

	function gutentor_get_acf_fields_by_location( $post_type ) {
		$fields = array();
		global $wpdb;

		$sql = "SELECT p.ID, p.post_title, p.post_name,p.post_content
            FROM $wpdb->posts p
            WHERE ( ( p.post_type = 'acf-field-group' AND ( p.post_status = 'publish' OR p.post_status = 'private' ) ) )";

		$result = $wpdb->get_results( $sql );
		$groups = array();

		if ( is_array( $result ) ) {
			foreach ( $result as $row ) {

				$content   = maybe_unserialize( $row->post_content );
				$locations = $content['location'];
				foreach ( $locations as $location ) {
					$rule = array();
					if ( isset( $location['param'] ) ) {
						$rule = $location;
					} elseif ( isset( $location[0]['param'] ) ) {
						$rule = $location[0];
					}
					if ( ! empty( $rule ) ) {
						if ( $rule['param'] == 'post_type' &&
							$rule['operator'] == '==' &&
							$rule['value'] == $post_type
						) {
							$groups[ $row->ID ] = array(
								'title' => $row->post_title,
								'name'  => $row->post_name,
							);
						}
					}
				}
			}
		}

		foreach ( $groups as $post_id => $data ) {
			$sql = "SELECT p.ID, p.post_title, p.post_name,p.post_excerpt
            FROM $wpdb->posts p
            WHERE ( ( p.post_parent = '$post_id' AND ( p.post_status = 'publish' OR p.post_status = 'private' ) ) )";

			$result = $wpdb->get_results( $sql );

			if ( is_array( $result ) ) {
				foreach ( $result as $row ) {
					$field = array();

					$field['ID']    = $row->ID;
					$field['label'] = $row->post_title;
					$field['name']  = $row->post_excerpt;

					$fields[] = $field;

				}
			}
		}
		return $fields;

	}
}

/**
 * Enabled Popup button.
 *
 * @since 2.1.0
 */
if ( ! function_exists( 'gutentor_setting_enable_popup' ) ) {
	function gutentor_setting_enable_popup() {

		if ( gutentor_is_edit_page() && 'gutentor-template' === get_post_type() ) {
			if ( has_term( 'popup', 'gutentor_template_taxonomies' ) ) {
				return gutentor_get_options( 'on-popup' );
			}
		}
		return false;
	}
}
