<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'Gutentor_Pro_Extend_Api' ) ) {
	/**
	 * Gutentor_Woo
	 *
	 * @package Gutentor
	 * @since 2.1.9
	 */
	class Gutentor_Pro_Extend_Api {

		/**
		 * Gets an instance of this object.
		 * Prevents duplicate instances which avoid artefacts and improves performance.
		 *
		 * @static
		 * @access public
		 * @since 2.1.9
		 * @return object
		 */
		public static function get_instance() {
			// Store the instance locally to avoid private static replication.
			static $instance = null;

			// Only run these methods if they haven't been ran previously.
			if ( null === $instance ) {
				$instance = new self();
			}

			// Always return the instance.
			return $instance;
		}

		/**
		 * Initialize the class
		 */
		public function run() {
			add_filter( 'gutentor_rest_prepare_data', array( $this, 'add_meta_data' ), 99999999, 3 );
			add_filter( 'gutentor_rest_prepare_data', array( $this, 'add_dynamic_element_data' ), 99999999, 3 );
			add_filter( 'gutentor_rest_prepare_term_data', array( $this, 'add_term_dynamic_element_data' ), 99999999, 3 );
		}

		/**
		 * Add Comment data
		 *
		 * @static
		 * @access public
		 * @since 2.1.9
		 * @return array
		 */
		public function add_meta_data( $data, $post, $request ) {
			$video_src_option = get_post_meta( $post->ID, 'gutentor_meta_video_src_option', true );
			$video_url        = get_post_meta( $post->ID, 'gutentor_meta_video_url', true );
			$video_id         = get_post_meta( $post->ID, 'gutentor_meta_video_id', true );
			if ( $video_src_option ) {
				$data['g_video_src'] = $video_src_option;
			}
			if ( $video_url ) {
				$data['g_video_url'] = $video_url;
			}
			if ( $video_id ) {
				$upload_video_url = wp_get_attachment_url( $video_id );
				if ( $upload_video_url ) {
					$data['g_upload_video_url'] = $upload_video_url;
				}
			}
			return $data;

		}

		/**
		 * Add Tax data
		 *
		 * @static
		 * @access public
		 * @since 2.1.9
		 * @return array
		 */
		public function add_dynamic_element_data( $data, $post, $request ) {

			$dynamic_element = gutentor_get_dynamic_element( $post );
			if ( $dynamic_element ) {
				$data['dynamic_element'] = $dynamic_element;
			}
			return $data;

		}

		/**
		 * Add Tax data
		 *
		 * @static
		 * @access public
		 * @since 2.1.9
		 * @return array
		 */
		public function add_term_dynamic_element_data( $data, $term, $request ) {

			$dynamic_element = gutentor_get_term_dynamic_element( $term );
			if ( $dynamic_element ) {
				$data['dynamic_element'] = $dynamic_element;
			}
			return $data;

		}
	}
}
Gutentor_Pro_Extend_Api::get_instance()->run();
